referrerpolicy=no-referrer-when-downgrade

set_pool_fee

Function set_pool_fee 

pub fn set_pool_fee<T: Config>(pool_id: T::PoolId, fee: Permill)
Set the per-pool swap fee for an existing pool, overriding the global Config::LPFee.

Requires Config::AdminOrigin. fee must not exceed Config::MaxSwapFee.

Emits Event::PoolFeeSet on success.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::set_pool_fee.